import { mapState } from "vuex";

const _mapState = {
  isSupertube: state => state.user.isSupertube, //是否超管
  currentCompany: (state) => state.user.currentCompany //当前选中的业务公司
}

const companyHelper = {
  computed: {
    ...mapState(_mapState)
  },
  methods: {
    /**
     * 当前公司发生改变时默认执行的方法,重置列表数据
     */
    onCompanyChangeInner() {
      const vm = this;
      const { searchList, pageInfo, parmValue } = vm;
      if (!searchList) return null;
      if (pageInfo) this.pageInfo.curr = 1;
      if (parmValue) this.parmValue.page = 1;
      this.searchList();
    },
    /**
     * 判断当前是否有选中公司 没有选中返回false并提示警告信息
    */
    isHasCurrentCompany(message = "请选择一家业务公司") {
      const current = this.currentCompany;
      if (!current) this.$message.warning(message);
      return !!current
    }
  },
  watch: {
    /**
     * 当前公司发生改变执行时默认执行mixins内部的onCompanyChangeInner
     * 当组件内部methods实现了onCompanyChange方法则调用组件内部的onCompanyChange方法
    */
    currentCompany: {
      handler() {
        const vm = this;
        const { onCompanyChange, onCompanyChangeInner } = vm;
        if (!vm.isSupertube) return null;
        onCompanyChange ? onCompanyChange() : onCompanyChangeInner();
      },
      deep: true
    }
  }
}

export default companyHelper
